@@ -21,7 +21,7 @@ import sys
 import dbus
 from BeautifulSoup import BeautifulStoneSoup
 
-version = "0.8.1"
+version = "0.8.2"
 feed_template_default = """
 <html>
     <head>
@@ -911,7 +911,7 @@ class Program:
         self.__log = []
 
 
-    def update_status(self, feed_config, action, item, i, feed_count, percent, j, url_count):
+    def update_status(self, feed_config, action, item, i, feed_count, percent, j, url_count, details):
         if self.__progress_window:
             fraction = None
             if percent:
@@ -921,6 +921,8 @@ class Program:
                 "%s (%u/%u)" % (feed_config.name, i, feed_count),
                 "%s %s" % (_(action), item))
         self.log("(%u/%u) %s %s" % (i, feed_count, _(action), item))
+        if details:
+            self.log(details)
 
 
     def update_feed_complete(self, feed_config, new_item_count):
@@ -944,7 +946,7 @@ class Program:
         if item[0]:
             gobject.idle_add(self.update_status, self.__progress_info[0], item[0], item[1],
                 self.__progress_info[1], self.__progress_info[2], item[2],
-                self.__progress_info[3], self.__progress_info[4])
+                self.__progress_info[3], self.__progress_info[4], item[3])
 
 
     def update_feeds(self, feed_configs):
@@ -1011,11 +1013,14 @@ class Program:
         self.__thread = Thread(target = self.update_feeds, args = (feeds_configs,))
         self.__thread.start()
         try:
+            gtk.gdk.threads_enter()
             if self.__progress_window.run() == gtk.RESPONSE_CANCEL:
                 self.__aborted = True
         finally:
+            self.__progress_window.hide()
             self.__progress_window.destroy()
             self.__progress_window = None
+            gtk.gdk.threads_leave()
 
 
     def refresh(self, source):
@@ -1502,7 +1507,7 @@ try:
 except ImportError:
     
     def connect_and_exec(auto, id, func, *args):
-        func(*args)
+        gobject.idle_add(func, *args)
 
 
     def get_connections():
